@@ -1,14 +1,14 @@
-'use strict';
+﻿'use strict';
 
 var TreeSelectFormHTML =  "<div id='jqxwindow2'>"+
-        "<div>Please Choose</div>"+
+        "<div>"+txtPleaseChooseFolder+"</div>"+
         "<div>"+
           "<div id=\"jqxTree\"></div>"+
           "<div><br></div>"+
           "<div></div>"+
             "<div>"+
-            "<button id=\"OK_btn2\">OK</button>&nbsp; &nbsp;"+
-            "<button id=\"Cancel_btn2\">Cancel</button>"+
+            "<button id=\"OK_btn2\">"+txtOK+"</button>&nbsp; &nbsp;"+
+            "<button id=\"Cancel_btn2\">"+txtCancel+"</button>"+
             "</div>"+
           "<div><br></div>"+
         "</div>"+
@@ -123,7 +123,7 @@ function ShowDirListingWaitDialog(data)
        directorylistingModelessAlertBig = needBig;
        var aheight = needBig ? 250 : 130;
        $("#ModelessAlertDlg_div").html( GModelessAlertHTML );
-       $('#jqxModelessAlertDlg').jqxWindow({ maxWidth: 400,  width:400, maxHeight:aheight, height:aheight, autoOpen: false, isModal: true, theme: GTheme, animationType: 'slide' });
+       $('#jqxModelessAlertDlg').jqxWindow({ maxWidth: 400,  width:400, maxHeight:aheight, height:aheight, autoOpen: false, isModal: true, theme: GTheme, animationType: 'none' });
        $('#jqxModelessAlertDlg').on('close', function (event)
        {
            $('#jqxModelessAlertDlg').jqxWindow('destroy');
@@ -145,17 +145,14 @@ function ShowDirListingWaitDialog(data)
    if (data.substring(0,21)=="RETRY: Visit Auth URL")
    {
       $("#jqxModelessMessage").html(
-      '<A target="_blank" HREF="'+data.substring(23,10000)+'">Click here to authorize Syncovery with the Cloud Service.</A>');
+      '<A target="_blank" HREF="'+data.substring(23,10000)+'">'+txtClickHeretoAuthorizeSyncoveryWithCloud+'.</A>');
       // window.open(data.substring(23,10000));
    }
    else
     if (data.substring(0,20)=="RETRY: Open Auth URL")
     {
       $("#jqxModelessMessage").html(
-      '<A target="_blank" HREF="'+data.substring(22,10000)+'">Click here to authorize Syncovery with the Cloud Service.</A><br><br>'+
-                     '<b>Important Note:</b> The authentication process may end<br>with a localhost URL and a page load error.<br><br>'+
-                     'Please change the localhost part of that URL to the<br><b>IP address</b> of the device which are you trying to<br>'+
-                     'authorize, and then reload that page.');
+      '<A target="_blank" HREF="'+data.substring(22,10000)+'">'+txtClickHeretoAuthorizeSyncoveryWithCloud+'</A><br><br>'+txtLocalHostAuthNote);
       // window.open(data.substring(23,10000));
     }
     else
@@ -183,7 +180,7 @@ function FolderTreeExpandFunc(event)
       function (indexInArray,value)
       {
           var item = theTree.getItem(value);
-          if (item && (item.label == 'Loading...'))
+          if (item && (item.label == txtLoading))
           {
               loaderItem = item;
               loader = true;
@@ -219,7 +216,9 @@ function FolderTreeExpandFunc(event)
                      }
                      catch(err)
                      {
-                       alert('Invalid folder listing received from server: '+err);
+                       console.log(txtInvalidFolderListingReceivedFromServer);
+                       console.error(err);
+                       alert(txtInvalidFolderListingReceivedFromServer+err);
                      }
                      theTree.addTo(items, docelement[0]);
                      theTree.removeItem(loaderItem.element);
@@ -318,7 +317,7 @@ function ExpandPathToSelectNode(parentnode)
  {
      if (GInDirTreeSelect)
      {
-        alert("Sorry, the directory selection dialog seems to be in use.");
+        alert(txtSorryTheDirectorySelectionDialogSeemsTo);
         return;
      }
 
@@ -395,7 +394,7 @@ function ExpandPathToSelectNode(parentnode)
                 if (parent1)
                 {
                    if (GSelectedDirStr.length>255)
-                      alert('Path too long: '+GSelectedDirStr); // probably an infinite recursion problem
+                      alert(txtPathTooLong+GSelectedDirStr); // probably an infinite recursion problem
                    else
                       getAllParents(parent1);
                 }
@@ -478,7 +477,9 @@ function ExpandPathToSelectNode(parentnode)
               }
               catch(err)
               {
-                alert('Invalid folder listing received from server: '+err);
+                console.log(txtInvalidFolderListingReceivedFromServer);
+                console.error(err);
+                alert(txtInvalidFolderListingReceivedFromServer+err);
               }
 
          }
@@ -504,7 +505,7 @@ function ExpandPathToSelectNode(parentnode)
      if ((TreeSource == null) || directorylistingCanceled)
      {
         if (!directorylistingCanceled)
-           alert("Cannot browse this storage.");
+           alert(txtCannotBrowseThisStorage);
         CallFreeDummy();
         return;
      }
@@ -523,7 +524,9 @@ function ExpandPathToSelectNode(parentnode)
      if (GRemainingPathToSelect!="")
         ExpandPathToSelectNode(undefined);
 
- $("#jqxwindow2").jqxWindow({ height: 440, width: 510, theme: GTheme, autoOpen: false, isModal: true, draggable: true , closeButtonAction: 'close'});
+ $("#jqxwindow2").jqxWindow({ height: 440, width: 510, theme: GTheme,
+          autoOpen: false, isModal: true, draggable: true,
+          closeButtonAction: 'close', animationType: 'none' });
 
  $("#jqxwindow2").on('resize', function (event) {
     var newWidth = $("#jqxwindow2").jqxWindow('width') - 20;
